EncodedOrigin

Enum EncodedOrigin 

#[repr(i32)]
pub enum EncodedOrigin { TopLeft = 1, TopRight = 2, BottomRight = 3, BottomLeft = 4, LeftTop = 5, RightTop = 6, RightBottom = 7, LeftBottom = 8, }
These values match the orientation www.exif.org/Exif2-2.PDF.

Variants



TopLeft = 1

Default



TopRight = 2

Reflected across y-axis



BottomRight = 3

Rotated 180



BottomLeft = 4

Reflected across x-axis



LeftTop = 5

Reflected across x-axis, Rotated 90 CCW



RightTop = 6

Rotated 90 CW



RightBottom = 7

Reflected across x-axis, Rotated 90 CW



LeftBottom = 8

Rotated 90 CCW

Implementations

Source

impl EncodedOrigin

pub const LAST: Self = EncodedOrigin::LeftBottom

pub const DEFAULT: Self = EncodedOrigin::TopLeft

pub fn to_matrix(self, size: impl Into<ISize>) -> Matrix

Given an width and height of the source data, returns a matrix that transforms the source rectangle with upper left corner at [0, 0] and origin to a correctly oriented destination rectangle of [0, 0, w, h].

pub fn to_matrix_inverse(self, size: impl Into<ISize>) -> Matrix

pub fn swaps_width_height(self) -> bool

Return true if the encoded origin includes a 90 degree rotation, in which case the width and height of the source data are swapped relative to a correctly oriented destination.