pub type BackendSemaphore = Handle<GrBackendSemaphore>;Expand description
Wrapper type for passing into and receiving data from Ganesh about a backend semaphore object.
Aliased Type
pub struct BackendSemaphore(/* private fields */);pub type BackendSemaphore = Handle<GrBackendSemaphore>;Wrapper type for passing into and receiving data from Ganesh about a backend semaphore object.
pub struct BackendSemaphore(/* private fields */);