Type Alias skia_safe::gpu::mtl::BackendContext

source ·
pub type BackendContext = Handle<GrMtlBackendContext>;

Aliased Type

struct BackendContext(/* private fields */);

Implementations

source

impl BackendContext

source

pub unsafe fn new(device: Handle, queue: Handle) -> Self

Safety

Unsafe because it expects various objects in form of c_void pointers.

This function retains all the non-null handles passed to it and releases them as soon the BackendContext is dropped.