pub type BackendContext = Handle<GrMtlBackendContext>;
struct BackendContext(/* private fields */);
Unsafe because it expects various objects in form of c_void pointers.
c_void
This function retains all the non-null handles passed to it and releases them as soon the BackendContext is dropped.
null