pub fn two_point_conical_gradient<'a>(
(start, start_radius): (impl Into<Point>, scalar),
(end, end_radius): (impl Into<Point>, scalar),
gradient: &Gradient<'_>,
local_matrix: impl Into<Option<&'a Matrix>>,
) -> Option<Shader>Expand description
Returns a shader that generates a conical gradient given two circles.
The gradient interprets the two circles according to the following HTML spec: http://dev.w3.org/html5/2dcontext/#dom-context-2d-createradialgradient
start: The center of the start circlestart_radius: Must be positive. The radius of the start circleend: The center of the end circleend_radius: Must be positive. The radius of the end circlegradient: Description of the colors and interpolation methodlocal_matrix: Optional local matrix